########## Data Visualization and Analysis 
########## Bocas 2017 zoanthid x OA experiment with Porites spp.
## Author: MD Johnson
## Updated: 12/17/2021

##MS Authors: Violet Doucette, Lucia Rodriguez, Andrew Altieri, Maggie D. Johnson

##MS Title: Negative  effects of a zoanthid competitor limit coral calcification more than ocean acidification 

## Getting started
#Set WD and load all libraries and data files

setwd("/xxx")

rm(list=ls())

#Load necessary libraries
library(ggplot2) # graphing
library(tidyr)
library(dplyr)
library(rcompanion) #plotting histograms
library(car)
library(cowplot)


#Load data files as csv
rawgrowth <- read.csv(file="growth.csv")
rawpolypcount <- read.csv(file="polypcount.csv")
rawpam <- read.csv(file="pam.csv")

## Set up for graphing
#Make custom theme for all plots
mytheme <- theme_classic() + theme(text = element_text(size=11))+
  theme(axis.text.x = element_text(size=10,colour="black"), axis.text.y =     
          element_text(size=10,colour="black"))+
  theme(plot.margin = unit(c(5.5,5.5,5.5,20), "pt"))+
  theme(panel.border = element_rect(colour = "black", fill=NA, size=0.5))+
  theme(axis.line = element_line(size = 0))


### Set color palette 
plot.colors<-c("steelblue", "coral")


################################################
################################################
####   Net Calcification of Porites sp. via Buoyant Weight

## prep dataframe and check that data loaded
growth <- rawgrowth
head(growth)
tail(growth)

## check class of treatments
class(growth$CO2)   #CO2 is a factor
class(growth$Zoanth)  #Zoanthid treatment is a factor

growth$CO2 <- as.factor(growth$CO2)
growth$Zoanth <- as.factor(growth$Zoanth)

##add column to df that is combined treatments (CO2 and Zoanthid) so can use treatment as a factor
growth <- unite(growth, "Treat", 3:4, sep = "_", remove = FALSE)

class(growth$Treat)
growth$Treat <- as.factor(growth$Treat)

#Boxplots for data visualization
ggplot(growth,aes(x=Zoanth, y=Growth, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='Net Growth')+ 
  mytheme


## Calculate tank means for use in subsequent graphs and analyses
growth.tank.mean<-growth %>%  
  group_by(CO2,Zoanth, Treat,Tank) %>%  
  summarize(N = sum(!is.na(Growth)),
            Mean = mean(Growth,na.rm=T),
            SD = sd(Growth,na.rm=T),
            SE =SD/sqrt(N))

head(growth.tank.mean)

#Boxplot by treatment to visualize data
ggplot(growth.tank.mean,aes(x=Zoanth, y=Mean, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='Net Growth')+ 
  mytheme

## Calculate treat means for plotting
growth.treat.mean<-growth.tank.mean %>%  
  group_by(Treat,Zoanth,CO2) %>%  
  summarize(N = sum(!is.na(Mean)),
            TMean = mean(Mean,na.rm=T),
            TSD = sd(Mean,na.rm=T),
            TSE = TSD/sqrt(N))

##Subset C and CxZ for plotting
growthsub <- growth.treat.mean %>% subset(Zoanth != "Z")
growthsub <- growthsub %>% subset(Zoanth != "Zcon")

growthtanksub <- growth.tank.mean %>%  subset (Zoanth !="Z") %>% 
  subset(Zoanth != "Zcon")

##Reorder treatments
growthsub$Zoanth <- factor(growthsub$Zoanth, levels = c("CxZ", "C"))

## Plot the treatment mean +/- SE as dots with tank means overlaid
Fig2a <- ggplot()+
  geom_bar(data=growthsub, aes(x=Zoanth, y=TMean, group=CO2, fill=CO2),stat="identity", position=position_dodge(), alpha=0.75, color = "black")+
  geom_errorbar(data=growthsub,aes(x=Zoanth, y=TMean,ymin=TMean-TSE,ymax=TMean+TSE,group=CO2),                 
                width=0,size=0.7,stat="Identity",position=position_dodge(0.9))+
   scale_fill_manual(values = plot.colors)+
  #geom_point(growthtanksub, mapping=aes(x=Zoanth, y=Mean, 
                                           #group=CO2),fill="darkgrey",color="darkgrey",position=position_dodge(1),size=2)+
  labs(x="Competition Treatment",y='Net Calcification')+ 
  mytheme 
Fig2a

##### Two-way anova with factors CO * Zoanth and using tank means as response variable
## First run model to generate residuals and evaluate normality and variances
growthaov <- aov(Mean~CO2*Zoanth, data=growthtanksub)
growthres <- resid(growthaov)

#Produce a histogram of the residuals.
plotNormalHistogram(growthres)

##QQ plots of residuals from lme model
qqnorm(growthres,
       ylab="Sample Quantiles for Rate")
qqline(growthres, 
       col="red")

##### Levene Test
leveneTest(Mean~ CO2*Zoanth,data=growthtanksub) # p = 0.9363

## Anova Table with p-values
summary(growthaov)



################################################
################################################
####   Zoanthid Growth (Polyps per fragment)

## prep dataframe and check that data loaded
count <- rawpolypcount
head(count)
tail(count)

## check class of treatments
class(count$CO2)   #CO2 is a factor
class(count$Zoanth)  #Zoanthid treatment is a factor

count$CO2 <- as.factor(count$CO2)
count$Zoanth <- as.factor(count$Zoanth)

##add column to df that is combined treatments (CO2 and Zoanthid) so can use treatment as a factor
count <- unite(count, "Treat", 3:4, sep = "_", remove = FALSE)

class(count$Treat)
count$Treat <- as.factor(count$Treat)

#Boxplots for data visualization
ggplot(count,aes(x=Zoanth, y=Change, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='Net count')+ 
  mytheme


## Calculate tank means for use in subsequent graphs and analyses
count.tank.mean<-count %>%  
  group_by(CO2,Zoanth, Treat,Tank) %>%  
  summarize(N = sum(!is.na(Change)),
            Mean = mean(Change,na.rm=T),
            SD = sd(Change,na.rm=T),
            SE =SD/sqrt(N))

head(count.tank.mean)

#Boxplot by treatment
ggplot(count.tank.mean,aes(x=Zoanth, y=Mean, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='Change in Polyps')+ 
  mytheme

## Calculate treat means for plotting
count.treat.mean<-count.tank.mean %>%  
  group_by(Treat,Zoanth,CO2) %>%  
  summarize(N = sum(!is.na(Mean)),
            TMean = mean(Mean,na.rm=T),
            TSD = sd(Mean,na.rm=T),
            TSE = TSD/sqrt(N))

##Reorder treatments
count.treat.mean$Treat <- factor(count.treat.mean$Treat, levels = c("CxZ", "Z"))

## Plot the treatment mean +/- SE as dots with tank means overlaid
Fig2b <- ggplot()+
  geom_bar(data=count.treat.mean, aes(x=Zoanth, y=TMean, group=CO2, fill=CO2),stat="identity", position=position_dodge(), alpha=0.75, color = "black")+
  geom_errorbar(data=count.treat.mean,aes(x=Zoanth, y=TMean,ymin=TMean-TSE,ymax=TMean+TSE,group=CO2),                 
                width=0,size=0.7,stat="Identity",position=position_dodge(0.9))+
  scale_fill_manual(values = plot.colors)+
  labs(x="Competition Treatment",y='Change in Polyps')+ 
  mytheme 
Fig2b

##### Two-way anova with factors CO * Zoanth and using tank means as response variable
## First run model to generate residuals and evaluate normality and variances
countaov <- aov(Mean~CO2*Zoanth, data=count.tank.mean)
countres <- resid(countaov)

#Produce a histogram of the residuals.
plotNormalHistogram(countres)

##QQ plots of residuals from lme model
qqnorm(countres,
       ylab="Sample Quantiles for Rate")
qqline(countres, 
       col="red")

##### Levene Test
leveneTest(Mean~ CO2*Zoanth,data=count.tank.mean) # p = 0.4235

## Anova Table with p-values
summary(countaov)


################################################
################################################
####   PAM Data

## prep dataframe and check that data loaded
PAM <- rawpam
head(PAM)
tail(PAM)

## check class of treatments
class(PAM$CO2)   #CO2 is a factor
class(PAM$Zoanth)  #Zoanthid treatment is a factor

PAM$CO2 <- as.factor(PAM$CO2)
PAM$Zoanth <- as.factor(PAM$Zoanth)

##add column to df that is combined treatments (CO2 and Zoanthid) so can use treatment as a factor
PAM <- unite(PAM, "Treat", 7:8, sep = "_", remove = FALSE)

class(PAM$Treat)
PAM$Treat <- as.factor(PAM$Treat)

#Boxplots for data visualization
ggplot(PAM,aes(x=Zoanth, y=Yield, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='Yield')+ 
  mytheme+
  facet_wrap(~Zone)


## Calculate fragment means
PAM.frag.mean<-PAM %>%  
  group_by(CO2,Zoanth, Treat,Tank,Rep,Zone) %>%  
  summarize(N = sum(!is.na(Yield)),
            Mean = mean(Yield,na.rm=T),
            SD = sd(Yield,na.rm=T),
            SE =SD/sqrt(N))

head(PAM.frag.mean)

## Calculate Tank mean from Frag Means
PAM.tank.mean<-PAM.frag.mean %>%  
  group_by(CO2,Zoanth, Treat,Tank,Zone) %>%  
  summarize(N = sum(!is.na(Rep)),
            TnkMean = mean(Mean,na.rm=T),
            TnkSD = sd(Mean,na.rm=T),
            TnkSE =TnkSD/sqrt(N))

head(PAM.tank.mean)

#Boxplot by treatment
ggplot(PAM.tank.mean,aes(x=Zoanth, y=TnkMean, fill=CO2))+ #group tells line what to connect
  geom_boxplot()+ #make box
  labs(x="Competitor Treatment",y='PAM')+ 
  mytheme+
  facet_wrap(~Zone)

## Calculate treat means for plotting
PAM.treat.mean<-PAM.tank.mean %>%  
  group_by(Treat,Zoanth,CO2,Zone) %>%  
  summarize(N = sum(!is.na(TnkMean)),
            TMean = mean(TnkMean,na.rm=T),
            TSD = sd(TnkMean,na.rm=T),
            TSE = TSD/sqrt(N))

##Reorder treatments
PAM.treat.mean$Zoanth <- factor(PAM.treat.mean$Zoanth, levels = c("CxZ","C", "Z"))

## Plot the treatment mean +/- SE as dots with tank means overlaid
Fig2c <- ggplot()+
  geom_bar(data=PAM.treat.mean, aes(x=Zoanth, y=TMean, group=CO2, fill=CO2),stat="identity", position=position_dodge(), alpha=0.75, color = "black")+
  geom_errorbar(data=PAM.treat.mean,aes(x=Zoanth, y=TMean,ymin=TMean-TSE,ymax=TMean+TSE,group=CO2),                 
                width=0,size=0.7,stat="Identity",position=position_dodge(0.9))+
  scale_fill_manual(values = plot.colors)+
  labs(x="Competition Treatment",y='Yield')+ 
  coord_cartesian(ylim=c(.3,.7))+
  mytheme+
  facet_wrap(~Zone)
Fig2c

##First subset the coral and zoanthid data so analyze separately
coral.pam <- PAM.tank.mean %>% subset(Zone == "Coral")
zoanth.pam <- PAM.tank.mean %>% subset(Zone == "Zoanthids")

#
##Analysis of Coral PAM data
#
##### Two-way anova with factors CO * Zoanth and using tank means as response variable
## First run model to generate residuals and evaluate normality and variances
coralaov <- aov(TnkMean~CO2*Zoanth, data=coral.pam)
coralres <- resid(coralaov)

#Produce a histogram of the residuals.
plotNormalHistogram(coralres)

##QQ plots of residuals from lme model
qqnorm(coralres,
       ylab="Sample Quantiles for Rate")
qqline(coralres, 
       col="red")

##### Levene Test
leveneTest(TnkMean~ CO2*Zoanth,data=coral.pam) # p = 0.5097

## Anova Table with p-values
summary(coralaov)


#
##Analysis of Zoanthid PAM data
#
##### Two-way anova with factors CO * Zoanth and using tank means as response variable
## First run model to generate residuals and evaluate normality and variances
zoanthaov <- aov(TnkMean~CO2*Zoanth, data=zoanth.pam)
zoanthres <- resid(zoanthaov)

#Produce a histogram of the residuals.
plotNormalHistogram(zoanthres)

##QQ plots of residuals from lme model
qqnorm(zoanthres,
       ylab="Sample Quantiles for Rate")
qqline(zoanthres, 
       col="red")

##### Levene Test
leveneTest(TnkMean~ CO2*Zoanth,data=zoanth.pam) # p = 0.7359

## Anova Table with p-values
summary(zoanthaov)


##### Figure 2 Panel
Fig2 <- plot_grid(Fig2a,Fig2b,Fig2c, ncol = 1)
Fig2
